==> veriloggen-1.8.4.tar.gz: veriloggen-1.8.4/tests/extension/types_/saturate_/sub/types_saturate_sub.py <==
from __future__ import absolute_import
from __future__ import print_function
import sys
import os

# the next line can be removed after installation
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(
    os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))))))

from veriloggen import *
import veriloggen.types.saturate as saturate


def mkLed():
    m = Module('blinkled')
    clk = m.Input('CLK')
    rst = m.Input('RST')
    led = m.OutputReg('LED', 8, initval=2 ** (8 - 1) - 1, signed=True)
    count = m.Reg('count', 10, initval=2 ** 10 - 1)

    a = m.Reg('a', 8, initval=0)

    seq = Seq(m, 'seq', clk, rst)

    seq(
        count(saturate.sub(count, 1, width=count.bit_length()))
    )

    seq.If(count == 0)(
        saturate.write(led, led - Int(1, signed=True))
    )

    seq(
        Systask('display', "LED:%d count:%d", led, count)
    )

    seq(
        saturate.write(a, 300)
    )

    return m


def mkTest():
    m = Module('test')

    # target instance
    led = mkLed()

    uut = Submodule(m, led, name='uut')
    clk = uut['CLK']
    rst = uut['RST']

    simulation.setup_waveform(m, uut, m.get_vars())
    simulation.setup_clock(m, clk, hperiod=5)
    init = simulation.setup_reset(m, rst, m.make_reset(), period=100)

    init.add(
        Delay(1000 * 100),
        Systask('finish'),
    )

    return m

if __name__ == '__main__':
    test = mkTest()
    verilog = test.to_verilog(filename='tmp.v')
    #verilog = test.to_verilog()
    print(verilog)

    sim = simulation.Simulator(test)
    rslt = sim.run()
    print(rslt)

    # sim.view_waveform()

==> veriloggen-2.2.0.tar.gz: veriloggen-2.2.0/tests/extension/types_/saturate_/sub/types_saturate_sub.py <==
from __future__ import absolute_import
from __future__ import print_function
import sys
import os

# the next line can be removed after installation
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(
    os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))))))

from veriloggen import *
import veriloggen.types.saturate as saturate


def mkLed():
    m = Module('blinkled')
    clk = m.Input('CLK')
    rst = m.Input('RST')
    led = m.OutputReg('LED', 8, initval=2 ** (8 - 1) - 1, signed=True)
    count = m.Reg('count', 10, initval=2 ** 10 - 1)

    a = m.Reg('a', 8, initval=0)

    seq = Seq(m, 'seq', clk, rst)

    seq(
        count(saturate.sub(count, 1, width=count.bit_length()))
    )

    seq.If(count == 0)(
        saturate.write(led, led - Int(1, signed=True))
    )

    seq(
        Systask('display', "LED:%d count:%d", led, count)
    )

    seq(
        saturate.write(a, 300)
    )

    return m


def mkTest():
    m = Module('test')

    # target instance
    led = mkLed()

    uut = Submodule(m, led, name='uut')
    clk = uut['CLK']
    rst = uut['RST']

    # simulation.setup_waveform(m, uut, m.get_vars())
    simulation.setup_clock(m, clk, hperiod=5)
    init = simulation.setup_reset(m, rst, m.make_reset(), period=100)

    init.add(
        Delay(1000 * 100),
        Systask('finish'),
    )

    return m


if __name__ == '__main__':
    test = mkTest()
    verilog = test.to_verilog(filename='tmp.v')
    #verilog = test.to_verilog()
    print(verilog)

    sim = simulation.Simulator(test)
    rslt = sim.run()
    print(rslt)

    # sim.view_waveform()
